importlib_metadata: Library to access the metadata for a Python package
=======================================================================

Description
-----------

importlib_metadata is a library to access the metadata for a Python package.
It is intended to be ported to Python 3.8.

License
-------

Apache Software License 


Upstream Contact
----------------

Home page: http://importlib-metadata.readthedocs.io/

